"""General template for the capability report"""
from string import Template
from typing import Dict

from ws_metrics.reporting.interfaces import RTemplate
from ws_metrics.schema import AbstractTextFile


class CapabilityReportTemplate(RTemplate):
    def __init__(self):
        self.file_type = ".txt"

    @staticmethod
    def total_by_type_template() -> Template:
        """
        Define template for this report

        :return: Report Template
        """

        string = "\nTotal number of $name capability executions: $total\n"

        return Template(string)

    @staticmethod
    def total_by_date_template():
        """
        Define template for this report

        :return: Report Template
        """

        string = "\nTotal number of $name executions between $begin and $end: $total\n"
        return Template(string)

    def render_template(self, title: str, data: Dict) -> AbstractTextFile:
        """
        render template to file

        :param title: filename
        :param data: data to render
        :return: an AbstractTextFile
        """

        if "end" in data:
            content = Template.substitute(self.total_by_date_template(), data)
        else:
            content = Template.substitute(self.total_by_type_template(), data)

        return AbstractTextFile(title, content)
