"""send emails from pims workflow

Revision ID: cccb662bd181
Revises: db9a82bc2020
Create Date: 2023-03-16 07:10:15.228023

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "cccb662bd181"
down_revision = "db9a82bc2020"
branch_labels = None
depends_on = None

old_split_sh = b"""#!/bin/sh
set -o errexit
export HOME=$TMPDIR
TILE=$(echo $1 | cut -d "/" -f 1)
PHCENTER=$(echo $1 | cut -d "/" -f 2)

# Get the measurement set path
{{^existing_restore}}
MS={{data_location}}/working/*.ms
{{/existing_restore}}
{{#existing_restore}}
MS={{existing_restore}}
{{/existing_restore}}

# Link it in the splits rawdata
ln -s $MS rawdata/

# Run CASA
./casa_envoy --split metadata.json PPR.xml

# Populate cache
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms

# Run quicklook if second parameter was given
if ! [[ -z "$2" ]]; then
    curl --request PUT --header "Content-Length: 0" $2
fi
"""

new_split_sh = b"""#!/bin/sh
export HOME=$TMPDIR
TILE=$(echo $1 | cut -d "/" -f 1)
PHCENTER=$(echo $1 | cut -d "/" -f 2)

# Get the measurement set path
{{^existing_restore}}
MS={{data_location}}/working/*.ms
{{/existing_restore}}
{{#existing_restore}}
MS={{existing_restore}}
{{/existing_restore}}

# Link it in the splits rawdata
ln -s $MS rawdata/

# Run CASA
./casa_envoy --split metadata.json PPR.xml

# Populate cache
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms

# If pimscache call failed, notify the user the workflow failed
if [[ $? -ne 0 ]] ; then
    # Set up for emails
    ADDRESS_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.vlassAnalystEmail"
    ADDRESS=$(./pycapo ${ADDRESS_CAPO_PROPERTY} | cut -d "'" -f 2)

    NOTIFICATION_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.serviceUrl"
    NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/email/send

    MESSAGE="PIMS Split workflow failed in when calling:
./pimscache cp -c {{vlass_product}} -t $TILE -p $PHCENTER working/*_split.ms.

Working directory: {{data_location}}
PIMS output directory: /lustre/aoc/cluster/pipeline/vlass_$(echo $CAPO_PROFILE | cut -d '-' -f 2)/cache/pims/$1
    "

    JSON="{\"destination_email\": \"$ADDRESS\", \"subject\": \"$SUBJECT\", \"message\": \"$MESSAGE\"}"

    /bin/curl --location \\
         --request POST $NOTIFICATION_URL \\
         --header 'Content-Type: application/json' \\
         --data-raw "$JSON"

    # Make sure we write the finished file even on failure
    /bin/date > finished
fi

# Run quicklook if second parameter was given
if ! [[ -z "$2" ]]; then
    curl --request PUT --header "Content-Length: 0" $2
fi

"""

old_write_finished_file_sh = b"""#!/bin/sh
set -o errexit

cd {{data_location}}
/bin/date > finished

"""

new_write_finished_file_sh = b"""#!/bin/sh
set -o errexit

cd {{data_location}}

# Set up for emails
ADDRESS_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.vlassAnalystEmail"
ADDRESS=$(./pycapo ${ADDRESS_CAPO_PROPERTY} | cut -d "'" -f 2)

NOTIFICATION_CAPO_PROPERTY="edu.nrao.workspaces.NotificationSettings.serviceUrl"
NOTIFICATION_URL=$(./pycapo ${NOTIFICATION_CAPO_PROPERTY} | cut -d "'" -f 2)/email/send

MESSAGE="PIMS Split workflow completed!

Working directory: {{data_location}}
PIMS output directory: /lustre/aoc/cluster/pipeline/vlass_$(echo $CAPO_PROFILE | cut -d '-' -f 2)/cache/pims/$1
"

JSON="{\"destination_email\": \"$ADDRESS\", \"subject\": \"$SUBJECT\", \"message\": \"$MESSAGE\"}"

# Send the email
/bin/curl --location \\
     --request POST $NOTIFICATION_URL \\
     --header 'Content-Type: application/json' \\
     --data-raw "$JSON"

/bin/date > finished

"""


def upgrade():
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='split.sh'
        """,
        new_split_sh,
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.sh'
        """,
        new_write_finished_file_sh,
    )


def downgrade():
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='split.sh'
        """,
        old_split_sh,
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s WHERE filename='write_finished_file.sh'
        """,
        old_write_finished_file_sh,
    )
